<%inherit file="/base/index.html" /> <%namespace file="/base/formViews.html" name="formViews" import="*"/> <%def name="heading()">

# History of Form ${c.form.id}

## Current Version

${formViews.formViewLong(c.form)}

## Previous Versions

% for formBackup in c.formBackups: <% formBackup.fromJSON() %> ${h.pretty_date(formBackup.datetimeModified)}
${formViews.formViewForHistory(formBackup)}
% endfor